const ipcRenderer = require('electron').ipcRenderer;

let $app =
{
    timers: {},
    storage: {},
    projects: [],
    options:{
        encoding:'utf-8',
        language:'rus'
    },
    getOptions: function(){
        ipcRenderer.once('get-options-reply', function(e, options){
            $app.options = options;
        });
        ipcRenderer.send('get-options');
    },
    convert:function(seconds)
    {
        let days = Math.floor(seconds / (24*60*60));
        seconds -= days * (24*60*60);
        let hours = Math.floor(seconds / (60*60));
        seconds -= hours * (60*60);
        let minutes = Math.floor(seconds / (60));
        seconds -= minutes * (60);
        if(String(minutes).length == 1) minutes = '0' + minutes;
        if(String(seconds).length == 1) seconds = '0' + seconds;
        return ((0<days)?(days+' Д, '):'')+hours+':'+minutes+':'+seconds;
    },
    calculate: function()
    {
        let total = 0;
        for (i in this.timers) total = total + this.timers[i].total;
        $('#totalTimer').text(this.convert(total));
    },
    getNewId: function()
    {
        let id = 0;
        for (i in this.storage) id = this.storage[i].id > id ? this.storage[i].id : id;
        return id + 1;
    },
    showIndex: function(){
        for (i in $app.timers) $app.timers[i].draw();
    },
    showArchive: function(){
        let archives = [];
        for (i in $app.projects){
            let total = 0;
            let works = [];
            for (t in $app.timers){
                if ($app.timers[t].project == $app.projects[i]) {
                    total = total + $app.timers[t].total;
                    works.push($app.timers[t].name + ' ('+$app.convert($app.timers[t].total)+')');
                }
            }
            archives[i] = {
                name: $app.projects[i],
                total: $app.convert(total),
                works: works.join(', ')
            };
        }
        let archivesBlock = '';
        for (i in archives) {
            archives[i]['i'] = i;
            archivesBlock += $view.draw($view.templates.archiveRow, archives[i]);
        }
        $('#myArchive').html(archivesBlock);
    },
    showOptions: function(){
        for (i in $app.options){
            //
        }
    },
    init: function()
    {
        ipcRenderer.on('show-page', function(event, page) {
            $view.generate(page);
        });
        ipcRenderer.on('delete-project', function(event, ttd) {
            for (i in ttd){
                if ($('[data-timer-id="'+ttd[i]+'"]').length) $('[data-timer-id="'+ttd[i]+'"]').remove();
            }
        });
        ipcRenderer.once('loaded-reply', function(event, timers) {
            if (Object.keys(timers).length > 0) {
                for (i in timers) {
                    $app.storage[i] = timers[i];
                    if (!in_array(timers[i].project, $app.projects)) $app.projects.push(timers[i].project);
                    if (timers[i].archive !== false && $view.page == 'index') continue;
                    $app.timers[i] = new Timer(timers[i]);
                }
                switch ($view.page) {
                    case 'index':
                        $app.showIndex()
                        break;

                    case 'archive':
                        $app.showArchive()
                        break;

                    case 'options':
                        $app.showOptions()
                        break;
                }
            }
        });
    }
};
